///////////////////////////////////////////////////////////////////////////////
/// \file GuiBitmaps_witbox_2.h
///
/// \author Ivan Galvez Junquera
///         Ruy Garcia
///         Victor Andueza 
///         Joaquin Herrero
///
/// \brief Bitmaps for Witbox 2 and Hephestos 2 UI
///
/// Copyright (c) 2015 BQ - Mundo Reader S.L.
/// http://www.bq.com
///
/// This file is free software; you can redistribute it and/or modify
/// it under the terms of either the GNU General Public License version 2 or 
/// later or the GNU Lesser General Public License version 2.1 or later, both
/// as published by the Free Software Foundation.
///
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
/// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
/// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
/// DEALINGS IN THE SOFTWARE.
///////////////////////////////////////////////////////////////////////////////

#ifndef GUI_BITMAPS_WITBOX_2_H
#define GUI_BITMAPS_WITBOX_2_H

#include <stdint.h>

#include "Marlin.h" //Required for PROGMEM macro

const static uint8_t icon_width = 24;
const static uint8_t icon_height = 22;
const static uint8_t little_icon_width = 5;
const static uint8_t little_icon_height = 7;
const static uint8_t logo_width = 33;
const static uint8_t logo_height = 33;
const static uint8_t serial_width = 27;
const static uint8_t serial_height = 42;
const static uint8_t widget_width = 50;
const static uint8_t widget_height = 22;
const static uint8_t splash_width = 60;
const static uint8_t splash_height = 45;
const static uint8_t emergency_width = 24;
const static uint8_t emergency_height = 23;
const static uint8_t progress_width = 108;
const static uint8_t progress_height = 2;
const static uint8_t inactivity_width = 16;
const static uint8_t inactivity_height = 18;
const static uint8_t icon_clock_width = 7;
const static uint8_t icon_clock_height = 7;

const uint8_t bits_nosd_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0xfe, 0x83,
  0x01, 0xaf, 0x82, 0x81, 0xab, 0x82, 0xc1, 0xab, 0x82, 0xc1, 0xff, 0x83,
  0xc1, 0xff, 0x83, 0xc1, 0xff, 0x83, 0x81, 0x77, 0x83, 0x81, 0xaf, 0x83,
  0x81, 0xff, 0x83, 0xc1, 0xaf, 0x83, 0xc1, 0x77, 0x83, 0xc1, 0xff, 0x83,
  0xc1, 0xff, 0x83, 0xc1, 0xff, 0x83, 0xc1, 0xff, 0x83, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_nosd_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x01, 0xfc,
  0xff, 0x50, 0xfd, 0x7f, 0x54, 0xfd, 0x3f, 0x54, 0xfd, 0x3f, 0x00, 0xfc,
  0x3f, 0x00, 0xfc, 0x3f, 0x00, 0xfc, 0x7f, 0x88, 0xfc, 0x7f, 0x50, 0xfc,
  0x7f, 0x00, 0xfc, 0x3f, 0x50, 0xfc, 0x3f, 0x88, 0xfc, 0x3f, 0x00, 0xfc,
  0x3f, 0x00, 0xfc, 0x3f, 0x00, 0xfc, 0x3f, 0x00, 0xfc, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_sd_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0xfe, 0x83,
  0x01, 0xaf, 0x82, 0x81, 0xab, 0x82, 0xc1, 0xab, 0x82, 0xc1, 0xff, 0x83,
  0xc1, 0xff, 0x83, 0xc1, 0xff, 0x83, 0x81, 0x93, 0x83, 0x81, 0x5d, 0x83,
  0x81, 0x5b, 0x83, 0xc1, 0x57, 0x83, 0xc1, 0x99, 0x83, 0xc1, 0xff, 0x83,
  0xc1, 0xff, 0x83, 0xc1, 0xff, 0x83, 0xc1, 0xff, 0x83, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_sd_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x01, 0xfc,
  0xff, 0x50, 0xfd, 0x7f, 0x54, 0xfd, 0x3f, 0x54, 0xfd, 0x3f, 0x00, 0xfc,
  0x3f, 0x00, 0xfc, 0x3f, 0x00, 0xfc, 0x7f, 0x6c, 0xfc, 0x7f, 0xa2, 0xfc,
  0x7f, 0xa4, 0xfc, 0x3f, 0xa8, 0xfc, 0x3f, 0x66, 0xfc, 0x3f, 0x00, 0xfc,
  0x3f, 0x00, 0xfc, 0x3f, 0x00, 0xfc, 0x3f, 0x00, 0xfc, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_filament_unload_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x08, 0x88,
  0x01, 0x08, 0x88, 0x01, 0x18, 0x8c, 0xf1, 0xe9, 0x8b, 0x01, 0xe8, 0x8b,
  0x01, 0xe8, 0x8b, 0x01, 0xe8, 0x8b, 0x01, 0xe8, 0x8b, 0x41, 0xe8, 0x8b,
  0xe1, 0xe8, 0x8b, 0xf1, 0xe9, 0x8b, 0x41, 0xe8, 0x8b, 0x41, 0xe8, 0x8b,
  0x41, 0x18, 0x8c, 0x41, 0x08, 0x88, 0x41, 0x08, 0x88, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_filament_unload_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xf7,
  0xff, 0xf7, 0xf7, 0xff, 0xe7, 0xf3, 0x0f, 0x16, 0xf4, 0xff, 0x17, 0xf4,
  0xff, 0x17, 0xf4, 0xff, 0x17, 0xf4, 0xff, 0x17, 0xf4, 0xbf, 0x17, 0xf4,
  0x1f, 0x17, 0xf4, 0x0f, 0x16, 0xf4, 0xbf, 0x17, 0xf4, 0xbf, 0x17, 0xf4,
  0xbf, 0xe7, 0xf3, 0xbf, 0xf7, 0xf7, 0xbf, 0xf7, 0xf7, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_filament_load_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x08, 0x88,
  0x41, 0x08, 0x88, 0x41, 0x18, 0x8c, 0xf1, 0xe9, 0x8b, 0x41, 0xe8, 0x8b,
  0x41, 0xe8, 0x8b, 0x01, 0xe8, 0x8b, 0x01, 0xe8, 0x8b, 0x41, 0xe8, 0x8b,
  0x41, 0xe8, 0x8b, 0x41, 0xe8, 0x8b, 0x41, 0xe8, 0x8b, 0x41, 0xe8, 0x8b,
  0xf1, 0x99, 0x8c, 0xe1, 0x88, 0x88, 0x41, 0x88, 0x88, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_filament_load_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xf7,
  0xbf, 0xf7, 0xf7, 0xbf, 0xe7, 0xf3, 0x0f, 0x16, 0xf4, 0xbf, 0x17, 0xf4,
  0xbf, 0x17, 0xf4, 0xff, 0x17, 0xf4, 0xff, 0x17, 0xf4, 0xbf, 0x17, 0xf4,
  0xbf, 0x17, 0xf4, 0xbf, 0x17, 0xf4, 0xbf, 0x17, 0xf4, 0xbf, 0x17, 0xf4,
  0x0f, 0x66, 0xf3, 0x1f, 0x77, 0xf7, 0xbf, 0x77, 0xf7, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_leveling_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x81, 0x00, 0x81, 0xc1, 0x01, 0x81, 0xe1, 0x03, 0x81, 0x81, 0xc0, 0x87,
  0x81, 0x80, 0x83, 0x81, 0x00, 0x81, 0x01, 0x00, 0x80, 0xe1, 0xff, 0x87,
  0x41, 0x18, 0x82, 0x01, 0x18, 0x80, 0x01, 0x18, 0x80, 0x01, 0x18, 0x80,
  0x01, 0x3c, 0x80, 0x81, 0xff, 0x81, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_leveling_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0x7f, 0xff, 0xfe, 0x3f, 0xfe, 0xfe, 0x1f, 0xfc, 0xfe, 0x7f, 0x3f, 0xf8,
  0x7f, 0x7f, 0xfc, 0x7f, 0xff, 0xfe, 0xff, 0xff, 0xff, 0x1f, 0x00, 0xf8,
  0xbf, 0xe7, 0xfd, 0xff, 0xe7, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xe7, 0xff,
  0xff, 0xc3, 0xff, 0x7f, 0x00, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_homing_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x18, 0x80, 0x01, 0xa4, 0x83, 0x01, 0xda, 0x82, 0x01, 0xa5, 0x82,
  0x81, 0x42, 0x83, 0x41, 0x81, 0x82, 0xa1, 0x00, 0x85, 0x61, 0x00, 0x86,
  0x41, 0x3c, 0x82, 0x41, 0x24, 0x82, 0x41, 0x24, 0x82, 0x41, 0x24, 0x82,
  0x41, 0x24, 0x82, 0xc1, 0xff, 0x83, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_homing_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xe7, 0xff, 0xff, 0x5b, 0xfc, 0xff, 0x25, 0xfd, 0xff, 0x5a, 0xfd,
  0x7f, 0xbd, 0xfc, 0xbf, 0x7e, 0xfd, 0x5f, 0xff, 0xfa, 0x9f, 0xff, 0xf9,
  0xbf, 0xc3, 0xfd, 0xbf, 0xdb, 0xfd, 0xbf, 0xdb, 0xfd, 0xbf, 0xdb, 0xfd,
  0xbf, 0xdb, 0xfd, 0x3f, 0x00, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_steppers_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x3c, 0x80,
  0x01, 0x24, 0x80, 0x01, 0x24, 0x80, 0x01, 0xe7, 0x80, 0xc1, 0xff, 0x83,
  0x41, 0x00, 0x82, 0xc1, 0xff, 0x83, 0x81, 0xff, 0x81, 0x81, 0xff, 0x81,
  0x81, 0xff, 0x81, 0x81, 0xff, 0x81, 0x81, 0xff, 0x81, 0x81, 0xff, 0x81,
  0xc1, 0xff, 0x83, 0x41, 0x00, 0x82, 0xc1, 0xff, 0x83, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_steppers_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xc3, 0xff,
  0xff, 0xdb, 0xff, 0xff, 0xdb, 0xff, 0xff, 0x18, 0xff, 0x3f, 0x00, 0xfc,
  0xbf, 0xff, 0xfd, 0x3f, 0x00, 0xfc, 0x7f, 0x00, 0xfe, 0x7f, 0x00, 0xfe,
  0x7f, 0x00, 0xfe, 0x7f, 0x00, 0xfe, 0x7f, 0x00, 0xfe, 0x7f, 0x00, 0xfe,
  0x3f, 0x00, 0xfc, 0xbf, 0xff, 0xfd, 0x3f, 0x00, 0xfc, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_steppers_off_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x3c, 0x80,
  0x01, 0x24, 0x80, 0x01, 0x24, 0x84, 0x01, 0xe7, 0x82, 0xc1, 0x7f, 0x81,
  0x41, 0x80, 0x82, 0xc1, 0x5f, 0x83, 0x81, 0xaf, 0x81, 0x81, 0xd7, 0x81,
  0x81, 0xeb, 0x81, 0x81, 0xf5, 0x81, 0x81, 0xfa, 0x81, 0x01, 0xfd, 0x81,
  0x81, 0xfe, 0x83, 0x41, 0x00, 0x82, 0xa1, 0xff, 0x83, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_steppers_off_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xc3, 0xff,
  0xff, 0xdb, 0xff, 0xff, 0xdb, 0xfb, 0xff, 0x18, 0xfd, 0x3f, 0x80, 0xfe,
  0xbf, 0x7f, 0xfd, 0x3f, 0xa0, 0xfc, 0x7f, 0x50, 0xfe, 0x7f, 0x28, 0xfe,
  0x7f, 0x14, 0xfe, 0x7f, 0x0a, 0xfe, 0x7f, 0x05, 0xfe, 0xff, 0x02, 0xfe,
  0x7f, 0x01, 0xfc, 0xbf, 0xff, 0xfd, 0x5f, 0x00, 0xfc, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_moveaxis_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x18, 0x80,
  0x01, 0x3c, 0x80, 0x01, 0x7e, 0x80, 0x01, 0x18, 0x80, 0x01, 0x18, 0x80,
  0x41, 0x18, 0x82, 0x61, 0x00, 0x86, 0xf1, 0xc3, 0x8f, 0xf1, 0xc3, 0x8f,
  0x61, 0x00, 0x86, 0x41, 0x18, 0x82, 0x01, 0x18, 0x80, 0x01, 0x18, 0x80,
  0x01, 0x7e, 0x80, 0x01, 0x3c, 0x80, 0x01, 0x18, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_moveaxis_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xe7, 0xff,
  0xff, 0xc3, 0xff, 0xff, 0x81, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xe7, 0xff,
  0xbf, 0xe7, 0xfd, 0x9f, 0xff, 0xf9, 0x0f, 0x3c, 0xf0, 0x0f, 0x3c, 0xf0,
  0x9f, 0xff, 0xf9, 0xbf, 0xe7, 0xfd, 0xff, 0xe7, 0xff, 0xff, 0xe7, 0xff,
  0xff, 0x81, 0xff, 0xff, 0xc3, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_temperature_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x03, 0x80,
  0x81, 0x04, 0x82, 0x41, 0x0b, 0x82, 0x41, 0x8a, 0x8f, 0x41, 0x0b, 0x82,
  0x41, 0x0a, 0x82, 0x41, 0x0b, 0x80, 0x41, 0x0a, 0x80, 0x41, 0x0b, 0x80,
  0x41, 0x0b, 0x80, 0x21, 0x13, 0x80, 0x91, 0x27, 0x80, 0xd1, 0xaf, 0x8f,
  0x91, 0x27, 0x80, 0x21, 0x10, 0x80, 0xc1, 0x0f, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_temperature_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff,
  0x7f, 0xfb, 0xfd, 0xbf, 0xf4, 0xfd, 0xbf, 0x75, 0xf0, 0xbf, 0xf4, 0xfd,
  0xbf, 0xf5, 0xfd, 0xbf, 0xf4, 0xff, 0xbf, 0xf5, 0xff, 0xbf, 0xf4, 0xff,
  0xbf, 0xf4, 0xff, 0xdf, 0xec, 0xff, 0x6f, 0xd8, 0xff, 0x2f, 0x50, 0xf0,
  0x6f, 0xd8, 0xff, 0xdf, 0xef, 0xff, 0x3f, 0xf0, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_settings_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0xe0, 0x80,
  0x01, 0x10, 0x81, 0x01, 0x88, 0x80, 0x01, 0x48, 0x84, 0x01, 0x48, 0x8a,
  0x01, 0x88, 0x89, 0x01, 0x04, 0x88, 0x01, 0x02, 0x84, 0x01, 0xc1, 0x83,
  0x81, 0x20, 0x80, 0x41, 0x10, 0x80, 0x21, 0x08, 0x80, 0x11, 0x04, 0x80,
  0x11, 0x02, 0x80, 0x11, 0x01, 0x80, 0xe1, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_settings_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x1f, 0xff,
  0xff, 0xef, 0xfe, 0xff, 0x77, 0xff, 0xff, 0xb7, 0xfb, 0xff, 0xb7, 0xf5,
  0xff, 0x77, 0xf6, 0xff, 0xfb, 0xf7, 0xff, 0xfd, 0xfb, 0xff, 0x3e, 0xfc,
  0x7f, 0xdf, 0xff, 0xbf, 0xef, 0xff, 0xdf, 0xf7, 0xff, 0xef, 0xfb, 0xff,
  0xef, 0xfd, 0xff, 0xef, 0xfe, 0xff, 0x1f, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_play_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x04, 0x80, 0x01, 0x0c, 0x80,
  0x01, 0x1c, 0x80, 0x01, 0x3c, 0x80, 0x01, 0x7c, 0x80, 0x01, 0x7c, 0x80,
  0x01, 0x3c, 0x80, 0x01, 0x1c, 0x80, 0x01, 0x0c, 0x80, 0x01, 0x04, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_play_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf3, 0xff,
  0xff, 0xe3, 0xff, 0xff, 0xc3, 0xff, 0xff, 0x83, 0xff, 0xff, 0x83, 0xff,
  0xff, 0xc3, 0xff, 0xff, 0xe3, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xfb, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_pause_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x81, 0xc3, 0x81, 0x81, 0xc3, 0x81,
  0x81, 0xc3, 0x81, 0x81, 0xc3, 0x81, 0x81, 0xc3, 0x81, 0x81, 0xc3, 0x81,
  0x81, 0xc3, 0x81, 0x81, 0xc3, 0x81, 0x81, 0xc3, 0x81, 0x81, 0xc3, 0x81,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_pause_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0x3c, 0xfe, 0x7f, 0x3c, 0xfe,
  0x7f, 0x3c, 0xfe, 0x7f, 0x3c, 0xfe, 0x7f, 0x3c, 0xfe, 0x7f, 0x3c, 0xfe,
  0x7f, 0x3c, 0xfe, 0x7f, 0x3c, 0xfe, 0x7f, 0x3c, 0xfe, 0x7f, 0x3c, 0xfe,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_stop_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x81, 0xff, 0x81, 0x81, 0xff, 0x81,
  0x81, 0xff, 0x81, 0x81, 0xff, 0x81, 0x81, 0xff, 0x81, 0x81, 0xff, 0x81,
  0x81, 0xff, 0x81, 0x81, 0xff, 0x81, 0x81, 0xff, 0x81, 0x81, 0xff, 0x81,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f }; 

const uint8_t bits_stop_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0x00, 0xfe, 0x7f, 0x00, 0xfe,
  0x7f, 0x00, 0xfe, 0x7f, 0x00, 0xfe, 0x7f, 0x00, 0xfe, 0x7f, 0x00, 0xfe,
  0x7f, 0x00, 0xfe, 0x7f, 0x00, 0xfe, 0x7f, 0x00, 0xfe, 0x7f, 0x00, 0xfe,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_change_filament_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x08, 0x88,
  0x41, 0x08, 0x88, 0x41, 0x18, 0x8c, 0xf1, 0xe9, 0x8b, 0x41, 0xe8, 0x8b,
  0x41, 0xe8, 0x8b, 0x01, 0xe8, 0x8b, 0x01, 0xe8, 0x8b, 0x01, 0xe8, 0x8b,
  0x01, 0xe8, 0x8b, 0x01, 0xe8, 0x8b, 0x01, 0xe8, 0x8b, 0xf1, 0xe9, 0x8b,
  0x01, 0x18, 0x8c, 0x01, 0x08, 0x88, 0x01, 0x08, 0x88, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_change_filament_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xf7,
  0xbf, 0xf7, 0xf7, 0xbf, 0xe7, 0xf3, 0x0f, 0x16, 0xf4, 0xbf, 0x17, 0xf4,
  0xbf, 0x17, 0xf4, 0xff, 0x17, 0xf4, 0xff, 0x17, 0xf4, 0xff, 0x17, 0xf4,
  0xff, 0x17, 0xf4, 0xff, 0x17, 0xf4, 0xff, 0x17, 0xf4, 0x0f, 0x16, 0xf4,
  0xff, 0xe7, 0xf3, 0xff, 0xf7, 0xf7, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_change_speed_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x41, 0x00, 0x82,
  0x61, 0x00, 0x86, 0xf1, 0xc3, 0x8f, 0x61, 0x00, 0x86, 0x41, 0x00, 0x82,
  0x01, 0x00, 0x80, 0x01, 0x3c, 0x80, 0x01, 0xdb, 0x80, 0x81, 0x81, 0x81,
  0x41, 0x80, 0x82, 0xc1, 0x40, 0x83, 0x21, 0x20, 0x84, 0x21, 0x10, 0x84,
  0x61, 0x18, 0x86, 0x21, 0x3c, 0x84, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_change_speed_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfd,
  0x9f, 0xff, 0xf9, 0x0f, 0x3c, 0xf0, 0x9f, 0xff, 0xf9, 0xbf, 0xff, 0xfd,
  0xff, 0xff, 0xff, 0xff, 0xc3, 0xff, 0xff, 0x24, 0xff, 0x7f, 0x7e, 0xfe,
  0xbf, 0x7f, 0xfd, 0x3f, 0xbf, 0xfc, 0xdf, 0xdf, 0xfb, 0xdf, 0xef, 0xfb,
  0x9f, 0xe7, 0xf9, 0xdf, 0xc3, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_back_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x02, 0x80,
  0x01, 0x03, 0x80, 0x81, 0x7f, 0x80, 0x01, 0x83, 0x80, 0x01, 0x02, 0x81,
  0x01, 0x00, 0x81, 0x01, 0x80, 0x80, 0x01, 0x78, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_back_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
  0xff, 0xfc, 0xff, 0x7f, 0x80, 0xff, 0xff, 0x7c, 0xff, 0xff, 0xfd, 0xfe,
  0xff, 0xff, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0x87, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_retry_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x3c, 0x80, 0x01, 0xc3, 0x80, 0x81, 0x00, 0x81, 0x41, 0x00, 0x82,
  0x41, 0x00, 0x82, 0x21, 0x80, 0x8f, 0x21, 0x00, 0x87, 0x21, 0x00, 0x82,
  0x21, 0x00, 0x80, 0x41, 0x00, 0x80, 0x41, 0x00, 0x80, 0x81, 0x00, 0x81,
  0x01, 0xc3, 0x80, 0x01, 0x3c, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_retry_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xc3, 0xff, 0xff, 0x3c, 0xff, 0x7f, 0xff, 0xfe, 0xbf, 0xff, 0xfd,
  0xbf, 0xff, 0xfd, 0xdf, 0x7f, 0xf0, 0xdf, 0xff, 0xf8, 0xdf, 0xff, 0xfd,
  0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0x7f, 0xff, 0xfe,
  0xff, 0x3c, 0xff, 0xff, 0xc3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_ok_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x81, 0x13, 0x81,
  0x41, 0x94, 0x80, 0x41, 0x54, 0x80, 0x41, 0x34, 0x80, 0x41, 0x54, 0x80,
  0x41, 0x94, 0x80, 0x81, 0x13, 0x81, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_ok_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xec, 0xfe,
  0xbf, 0x6b, 0xff, 0xbf, 0xab, 0xff, 0xbf, 0xcb, 0xff, 0xbf, 0xab, 0xff,
  0xbf, 0x6b, 0xff, 0x7f, 0xec, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_about[] PROGMEM = {
  0x00, 0x80, 0x03, 0x00, 0x00, 0x00, 0xc0, 0x07, 0x00, 0x00, 0x00, 0xc0,
  0x07, 0x00, 0x00, 0x80, 0xc3, 0x87, 0x03, 0x00, 0xc0, 0x87, 0xc3, 0x07,
  0x00, 0xc0, 0x07, 0xc0, 0x07, 0x00, 0xc0, 0x07, 0xc0, 0x07, 0x00, 0x80,
  0x03, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x01,
  0x00, 0x00, 0x00, 0xf0, 0x01, 0x00, 0x00, 0x00, 0xf0, 0x01, 0x00, 0x00,
  0x00, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x0e, 0x00, 0x00, 0x00, 0x00, 0x1f, 0x00, 0x00,
  0x00, 0x00, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x1f, 0x00, 0x00, 0x00, 0x00,
  0x0e, 0x00, 0x00, 0x00, 0x00 };

const uint8_t bits_x_axis_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x22, 0x80, 0x01, 0x22, 0x80, 0x01, 0x14, 0x80, 0x01, 0x08, 0x80,
  0x01, 0x14, 0x80, 0x01, 0x22, 0x80, 0x01, 0x22, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_x_axis_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xdd, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xf7, 0xff,
  0xff, 0xeb, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_y_axis_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x22, 0x80, 0x01, 0x22, 0x80, 0x01, 0x22, 0x80, 0x01, 0x14, 0x80,
  0x01, 0x08, 0x80, 0x01, 0x08, 0x80, 0x01, 0x08, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_y_axis_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xdd, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xeb, 0xff,
  0xff, 0xf7, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_z_axis_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x3e, 0x80, 0x01, 0x20, 0x80, 0x01, 0x10, 0x80, 0x01, 0x08, 0x80,
  0x01, 0x04, 0x80, 0x01, 0x02, 0x80, 0x01, 0x3e, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_z_axis_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xc1, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff,
  0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xc1, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_e_axis_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x3e, 0x80, 0x01, 0x02, 0x80, 0x01, 0x02, 0x80, 0x01, 0x1e, 0x80,
  0x01, 0x02, 0x80, 0x01, 0x02, 0x80, 0x01, 0x3e, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_e_axis_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xc1, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xe1, 0xff,
  0xff, 0xfd, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xc1, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_01mm_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0xe1, 0x40, 0x80, 0x11, 0x61, 0x80, 0x91, 0x41, 0x80, 0x51, 0x41, 0x80,
  0x31, 0x41, 0x80, 0x11, 0x4d, 0x80, 0xe1, 0xec, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x96, 0x85, 0x01, 0xaa, 0x8a, 0x01, 0xaa, 0x8a,
  0x01, 0xa2, 0x88, 0x01, 0xa2, 0x88, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_01mm_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0x1f, 0xbf, 0xff, 0xef, 0x9e, 0xff, 0x6f, 0xbe, 0xff, 0xaf, 0xbe, 0xff,
  0xcf, 0xbe, 0xff, 0xef, 0xb2, 0xff, 0x1f, 0x13, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0x69, 0xfa, 0xff, 0x55, 0xf5, 0xff, 0x55, 0xf5,
  0xff, 0x5d, 0xf7, 0xff, 0x5d, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_1mm_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x21, 0x00, 0x80, 0x31, 0x00, 0x80, 0x21, 0x00, 0x80, 0x21, 0x00, 0x80,
  0x21, 0x00, 0x80, 0x21, 0x00, 0x80, 0x71, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x96, 0x85, 0x01, 0xaa, 0x8a, 0x01, 0xaa, 0x8a,
  0x01, 0xa2, 0x88, 0x01, 0xa2, 0x88, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_1mm_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xdf, 0xff, 0xff, 0xcf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xff,
  0xdf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0x8f, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0x69, 0xfa, 0xff, 0x55, 0xf5, 0xff, 0x55, 0xf5,
  0xff, 0x5d, 0xf7, 0xff, 0x5d, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_10mm_normal[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0x02, 0x00, 0x40, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x21, 0x0e, 0x80, 0x31, 0x11, 0x80, 0x21, 0x19, 0x80, 0x21, 0x15, 0x80,
  0x21, 0x13, 0x80, 0x21, 0x11, 0x80, 0x71, 0x0e, 0x80, 0x01, 0x00, 0x80,
  0x01, 0x00, 0x80, 0x01, 0x96, 0x85, 0x01, 0xaa, 0x8a, 0x01, 0xaa, 0x8a,
  0x01, 0xa2, 0x88, 0x01, 0xa2, 0x88, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
  0x02, 0x00, 0x40, 0xfc, 0xff, 0x3f };

const uint8_t bits_10mm_focused[] PROGMEM = {
  0xfc, 0xff, 0x3f, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xdf, 0xf1, 0xff, 0xcf, 0xee, 0xff, 0xdf, 0xe6, 0xff, 0xdf, 0xea, 0xff,
  0xdf, 0xec, 0xff, 0xdf, 0xee, 0xff, 0x8f, 0xf1, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0x69, 0xfa, 0xff, 0x55, 0xf5, 0xff, 0x55, 0xf5,
  0xff, 0x5d, 0xf7, 0xff, 0x5d, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfe, 0xff, 0x7f, 0xfc, 0xff, 0x3f };

const uint8_t bits_sd_small[] PROGMEM = {
  0x1c, 0x16, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f };

const uint8_t bits_clock_small[] PROGMEM = {
  0x00, 0x0e, 0x19, 0x15, 0x11, 0x0e, 0x00 };

const uint8_t bits_temperature_small[] PROGMEM = {
  0x04, 0x0a, 0x0a, 0x0a, 0x11, 0x11, 0x0e };

const uint8_t bits_back_small[] PROGMEM = {
  0x00, 0x00, 0x04, 0x06, 0x1f, 0x06, 0x04 };

const uint8_t bits_folder_small[] PROGMEM = {
  0x00, 0x00, 0x07, 0x1d, 0x11, 0x11, 0x1f };

const uint8_t bits_updir_small[] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x15 };

const uint8_t bits_logo_splash[] PROGMEM = {
  0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8,
  0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 0x03, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0xfc, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc,
  0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 0x03, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0xf8, 0x01, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x01, 0xf0,
  0x00, 0x78, 0x00, 0x00, 0x00, 0xf0, 0x03, 0x00, 0x00, 0xfc, 0x00, 0x00,
  0x00, 0xf8, 0x07, 0x00, 0x00, 0xfe, 0x01, 0x00, 0x00, 0xf8, 0x07, 0x00,
  0x00, 0xfe, 0x01, 0x00, 0x00, 0xf8, 0x07, 0x00, 0x00, 0xfe, 0x01, 0x00,
  0x00, 0xf8, 0x07, 0x00, 0x00, 0xfe, 0x01, 0x00, 0x00, 0xf0, 0x03, 0x00,
  0x00, 0xfc, 0x00, 0x00, 0x00, 0xe0, 0x01, 0x00, 0x00, 0x78, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x07,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x0f, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0xf0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x0f,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x0f, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0xe0, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x03,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };

const uint8_t bits_logo_about[] PROGMEM = {
  0x00, 0x80, 0x03, 0x00, 0x00, 0x00, 0xc0, 0x07, 0x00, 0x00, 0x00, 0xc0,
  0x07, 0x00, 0x00, 0x80, 0xc3, 0x07, 0x00, 0x00, 0xc0, 0x87, 0x83, 0x03,
  0x00, 0xc0, 0x07, 0xc0, 0x07, 0x00, 0xc0, 0x07, 0xc0, 0x07, 0x00, 0x80,
  0x03, 0xc0, 0x07, 0x00, 0x00, 0x00, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x01,
  0x00, 0x00, 0x00, 0xf0, 0x01, 0x00, 0x00, 0x00, 0xf0, 0x01, 0x00, 0x00,
  0x00, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x0e, 0x00, 0x08, 0x00, 0x00, 0x1f, 0x00, 0x08,
  0x00, 0x00, 0x1f, 0x00, 0x08, 0x00, 0x00, 0x1f, 0x00, 0x68, 0x30, 0x00,
  0x0e, 0x00, 0x98, 0xc8, 0x00, 0x00, 0x00, 0x08, 0x85, 0x00, 0x00, 0x00,
  0x08, 0x85, 0x00, 0x00, 0x00, 0x98, 0xc8, 0x00, 0x00, 0x00, 0x60, 0xb0,
  0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00,
  0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };

const uint8_t bits_serial[] PROGMEM = {
  0x00, 0x00, 0xfc, 0x07, 0x00, 0x00, 0x04, 0x04, 0x00, 0x00, 0x04, 0x04,
  0x00, 0x00, 0x04, 0x04, 0x00, 0x00, 0x04, 0x04, 0x00, 0x00, 0x04, 0x04,
  0x00, 0x00, 0x04, 0x04, 0x00, 0x00, 0x04, 0x04, 0x00, 0x00, 0xfc, 0x07,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00,
  0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x60, 0x66, 0x66, 0x00,
  0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x20, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x03, 0x00, 0x00,
  0x02, 0x02, 0x00, 0x00, 0x02, 0x02, 0x00, 0x00, 0x02, 0x02, 0x00, 0x00,
  0x02, 0x02, 0x00, 0x00, 0x02, 0x02, 0x00, 0x00, 0x02, 0x02, 0x00, 0x00,
  0x02, 0x02, 0x00, 0x00, 0xfe, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };

const uint8_t bits_temperature_widget_normal[] PROGMEM = {
  0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x01, 0x18, 0x00,
  0x00, 0x00, 0x00, 0x02, 0x01, 0x24, 0x00, 0x00, 0x00, 0x00, 0x02, 0x01,
  0x5a, 0x00, 0x00, 0x00, 0x00, 0x02, 0x01, 0x52, 0x00, 0x00, 0x00, 0x00,
  0x02, 0x01, 0x5a, 0x00, 0x00, 0x00, 0x00, 0x02, 0x01, 0x52, 0x00, 0x00,
  0x00, 0x00, 0x02, 0x01, 0x5a, 0x00, 0x00, 0x00, 0x00, 0x02, 0x01, 0x52,
  0x00, 0x00, 0x00, 0x00, 0x02, 0x01, 0x5a, 0x00, 0x00, 0x00, 0x00, 0x02,
  0x01, 0x5a, 0x00, 0x00, 0x00, 0x00, 0x02, 0x01, 0x99, 0x00, 0x00, 0x00,
  0x00, 0x02, 0x81, 0x3c, 0x01, 0x00, 0x00, 0x00, 0x02, 0x81, 0x7e, 0x01,
  0x00, 0x00, 0x00, 0x02, 0x81, 0x3c, 0x01, 0x00, 0x00, 0x00, 0x02, 0x01,
  0x81, 0x00, 0x00, 0x00, 0x00, 0x02, 0x01, 0x7e, 0x00, 0x00, 0x00, 0x00,
  0x02, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x02, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x01, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00 };

const uint8_t bits_temperature_widget_focused[] PROGMEM = {
  0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0xfe, 0xff, 0xff, 0xff, 0xff,
  0xff, 0x01, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x03, 0xff, 0xe7, 0xff,
  0xff, 0xff, 0xff, 0x03, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xff, 0x03, 0xff,
  0xa5, 0xff, 0xff, 0xff, 0xff, 0x03, 0xff, 0xad, 0xff, 0xff, 0xff, 0xff,
  0x03, 0xff, 0xa5, 0xff, 0xff, 0xff, 0xff, 0x03, 0xff, 0xad, 0xff, 0xff,
  0xff, 0xff, 0x03, 0xff, 0xa5, 0xff, 0xff, 0xff, 0xff, 0x03, 0xff, 0xad,
  0xff, 0xff, 0xff, 0xff, 0x03, 0xff, 0xa5, 0xff, 0xff, 0xff, 0xff, 0x03,
  0xff, 0xa5, 0xff, 0xff, 0xff, 0xff, 0x03, 0xff, 0x66, 0xff, 0xff, 0xff,
  0xff, 0x03, 0x7f, 0xc3, 0xfe, 0xff, 0xff, 0xff, 0x03, 0x7f, 0x81, 0xfe,
  0xff, 0xff, 0xff, 0x03, 0x7f, 0xc3, 0xfe, 0xff, 0xff, 0xff, 0x03, 0xff,
  0x7e, 0xff, 0xff, 0xff, 0xff, 0x03, 0xff, 0x81, 0xff, 0xff, 0xff, 0xff,
  0x03, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x03, 0xfe, 0xff, 0xff, 0xff,
  0xff, 0xff, 0x01, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00 };

const uint8_t bits_emergency[] PROGMEM = {
  0x00, 0x18, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x7e, 0x00,
  0x00, 0x7e, 0x00, 0x00, 0xff, 0x00, 0x00, 0xff, 0x00, 0x80, 0xff, 0x01,
  0x80, 0xe7, 0x01, 0xc0, 0xe7, 0x03, 0xc0, 0xe7, 0x03, 0xe0, 0xe7, 0x07,
  0xe0, 0xe7, 0x07, 0xf0, 0xe7, 0x0f, 0xf0, 0xe7, 0x0f, 0xf8, 0xff, 0x1f,
  0xf8, 0xff, 0x1f, 0xfc, 0xe7, 0x3f, 0xfc, 0xe7, 0x3f, 0xfe, 0xff, 0x7f,
  0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff };
  
const uint8_t bits_progress_1[] PROGMEM = {
  0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e,
  0x1e, 0x0e, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f,
  0x0f, 0x0f, 0x0f, 0x0f };

const uint8_t bits_progress_2[] PROGMEM = {
  0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c,
  0x3c, 0x0c, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e, 0x1e,
  0x1e, 0x1e, 0x1e, 0x0e };

const uint8_t bits_progress_3[] PROGMEM = {
  0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78,
  0x78, 0x08, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c,
  0x3c, 0x3c, 0x3c, 0x0c };

const uint8_t bits_progress_4[] PROGMEM = {
  0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
  0xf0, 0x00, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78,
  0x78, 0x78, 0x78, 0x08 };

const uint8_t bits_progress_5[] PROGMEM = {
  0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1,
  0xe1, 0x01, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
  0xf0, 0xf0, 0xf0, 0x00 };

const uint8_t bits_progress_6[] PROGMEM = {
  0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3,
  0xc3, 0x03, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1, 0xe1,
  0xe1, 0xe1, 0xe1, 0x01 };

const uint8_t bits_progress_7[] PROGMEM = {
  0x87, 0x87, 0x87, 0x87, 0x87, 0x87, 0x87, 0x87, 0x87, 0x87, 0x87, 0x87,
  0x87, 0x07, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3,
  0xc3, 0xc3, 0xc3, 0x03 };

const uint8_t bits_progress_8[] PROGMEM = {
  0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f,
  0x0f, 0x0f, 0x87, 0x87, 0x87, 0x87, 0x87, 0x87, 0x87, 0x87, 0x87, 0x87,
  0x87, 0x87, 0x87, 0x07 };

const uint8_t icon_inactivity[] PROGMEM = {
  0x00, 0x00, 0xc0, 0x03, 0x40, 0x02, 0x40, 0x42, 0x70, 0x2e, 0xfc, 0x17,
  0x04, 0x28, 0xfc, 0x35, 0xf8, 0x1a, 0x78, 0x1d, 0xb8, 0x1e, 0x58, 0x1f,
  0xa8, 0x1f, 0xd0, 0x1f, 0xe8, 0x3f, 0x04, 0x20, 0xfa, 0x3f, 0x00, 0x00 };

const uint8_t icon_clock[] PROGMEM = {
  0x1c, 0x22, 0x49, 0x59, 0x41, 0x22, 0x1c };

#endif //GUI_BITMAPS_WITBOX_2_H
